GoogleSearch_services_types.urn_GoogleSearch

|  | ## Cheshire3 Object Model: Class urn_GoogleSearch

Module GoogleSearch_services_types :: Class urn_GoogleSearch

## Class urn_GoogleSearch
source code

Nested Classes | [hide private]
DirectoryCategory_Def |
ResultElementArray_Def |
DirectoryCategoryArray_Def |
ResultElement_Def |
GoogleSearchResult_Def |

Class Variables

targetNamespace |

Class Variable Details

    ### targetNamespace Value:
        'urn:GoogleSearch'